import { Mime } from "../common/Mime";
import { Http } from "../http/Http";
import { StateMachineTransition } from "../common/StateMachineTransition";
import { AbstractModel } from "./AbstractModel";
export declare const Model: (config?: {
    /**
     * Description about this metadata.
     */
    description?: string | undefined;
    /**
     * Override a model by using it id so that any service that uses the old model will use this model instead.
     * To support backward compatible, this new model should extends from the old model.
     */
    override?: (new () => AbstractModel) | undefined;
    /**
     * Ignore some http method to prevent auto generation of routes and/or endpoints
     */
    ignoreHttpMethods?: Http[] | undefined;
} | undefined) => <T extends new (...args: any[]) => AbstractModel>(constructor: T) => T;
export declare const PK: (config?: {
    autoIncrement?: boolean | undefined;
} | undefined) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const FK: (config: {
    model: {
        new (): AbstractModel;
    };
    cascade?: boolean;
}) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const Indexing: (config?: {
    group?: string | undefined;
} | undefined) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const BigInt: (config?: {
    isBigInt?: boolean | undefined;
} | undefined) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const Unique: (name?: string | undefined) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const ServerValue: () => (prototype: AbstractModel, propertyKey: string) => void;
export declare const URI: (config?: {
    mimeType: Mime;
} | undefined) => (prototype: any, propertyKey: string) => void;
export declare const StateMachine: <T>(config: {
    transition: StateMachineTransition<T>[];
}) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const Searchable: () => (prototype: AbstractModel, propertyKey: string) => void;
export declare const Timestamp: () => (prototype: AbstractModel, propertyKey: string) => void;
export declare const TextField: (config?: {
    length?: number | undefined;
    caseSensitive?: boolean | undefined;
    accentSensitive?: boolean | undefined;
} | undefined) => (prototype: AbstractModel, propertyKey: string) => void;
export declare const ServerModify: <T>(modifyFn?: ((value: T) => T) | undefined) => (prototype: AbstractModel, propertyKey: string) => void;
//# sourceMappingURL=decorator.d.ts.map